freeslot(
	--objects
	"MT_KIDBULLET",
	"MT_KID_GIBS",
	--player states
	"S_PLAY_KIDFROZE", 
	"S_PLAY_KIDFALL",
	"S_PLAY_KIDJUMP",
	"S_PLAY_KIDSTARTJUMP",
	"S_PLAY_EPICWIN",
	--player sprites
	"SPR2_FROZ",
	"SPR2_KFAL",
	"SPR2_WIN_",
	--object sprites
	"SPR_KBUL",
	"SPR_KGIB",
	--object states
	"S_KBUL",
	"S_KID_GIBS",
	"S_KBULDEATH",
	--sounds
	"sfx_kidfir",
	"sfx_kidhit",
	"sfx_kiddie",
	"sfx_kidjmp",
	"sfx_kidjp2",
	"sfx_kiddsh",
	--skincolors
	"SKINCOLOR_BLOOD"
)

--bit of help here from lach, thankss!
local function prepfof(fof)
	return fof and fof.valid and fof.flags & (FF_EXISTS|FF_BUSTUP) == (FF_EXISTS|FF_BUSTUP)
end

local function killwall(mobj, line)
	for fof in line.ffloors()
		if prepfof(fof)
		and fof.topheight > mobj.z+mobj.height and fof.bottomheight < mobj.z
			EV_CrumbleChain(line, fof)
		end
	end
end

local function A_KidBulletDeath(m)
	local kid = m.target
	if kid and kid.kid
		kid.kid.bullets = $ - 1
	end
	local radius = m.radius + FixedMul(m.info.speed, m.scale)
	searchBlockmap("lines", function(mo, line)
		local sector = {line.frontsector, line.backsector}
		for i = 1, #sector
			killwall(mo,sector[i])
		end        
	end, m, m.x - radius, m.x + radius, m.y - radius, m.y + radius)
end

states[S_PLAY_KIDFROZE] = {SPR_PLAY, SPR2_FROZ, 1, nil, 0, 0, S_PLAY_KIDFROZE}
states[S_PLAY_KIDSTARTJUMP] = {SPR_PLAY, SPR2_JUMP, 2, nil, 0, 0, S_PLAY_KIDJUMP}
states[S_PLAY_KIDJUMP] = {SPR_PLAY, SPR2_SPNG, -1, nil, 0, 0, S_PLAY_KIDJUMP}
states[S_PLAY_KIDFALL] = {SPR_PLAY, SPR2_KFAL|FF_ANIMATE, 4, nil, 1, 2, S_PLAY_FALL}
states[S_KBUL] = {SPR_KBUL, A|FF_ANIMATE|FF_FULLBRIGHT, 4, nil, 1, 2, S_KBUL}
states[S_KBULDEATH] = {SPR_NULL, A, 1, A_KidBulletDeath, 0, 0, S_NULL}
states[S_KID_GIBS] = {SPR_KGIB, A, -1, nil, 0, 0, S_NULL}
states[S_PLAY_EPICWIN] = {SPR_PLAY, SPR2_WIN_, 4, nil, 0, 0, S_PLAY_EPICWIN}

mobjinfo[MT_KID_GIBS] = {
	spawnstate = S_KID_GIBS,
	spawnhealth = 1,
    deathstate = S_NULL,
    speed = FRACUNIT,
    radius = FRACUNIT,
    height = FRACUNIT,
	flags = MF_SCENERY
}

mobjinfo[MT_KIDBULLET] = {
	spawnstate = S_KBUL,
	spawnhealth = 20,
	seesound = sfx_kidfir,
	reactiontime = 32,
	deathstate = S_KBULDEATH,
	speed = 55*FRACUNIT,
	radius = 2*FRACUNIT,
	height = 4*FRACUNIT,
	damage = 1,
	flags = MF_NOBLOCKMAP|MF_MISSILE|MF_NOGRAVITY
}

sfxinfo[sfx_kidjmp] = {
	flags = SF_NOMULTIPLESOUND,
	caption = "Jump"
}

sfxinfo[sfx_kidjp2] = {
	flags = SF_NOMULTIPLESOUND,
	caption = "Doublejump"
}

sfxinfo[sfx_kidfir] = {
	caption = "Fire"
}

sfxinfo[sfx_kidhit] = {
	caption = "Hit"
}

sfxinfo[sfx_kiddie] = {
	caption = "/",
	flags = SF_X8AWAYSOUND
}

sfxinfo[sfx_kiddsh] = {
	caption = "/"
}

skincolors[SKINCOLOR_BLOOD] = {
    name = "Blood",
    ramp = {0,48,210,33,34,37,38,40,41,43,44,186,187,169,169,158},
    invcolor = SKINCOLOR_ORANGE,
    invshade = 9,
    chatcolor = V_BLUEMAP,
    accessible = true
}

addHook("AbilitySpecial", function(p)
	if p.mo.skin == "thekid" and not (p.pflags & PF_THOKKED)
		S_StartSound(p.mo,sfx_kidjp2)
		p.pflags = $ & ~PF_JUMPED
		p.jumpfactor = FixedMul($, 4*FU/5) + (FU/10)
		P_DoJump(p,false)
		p.jumpfactor = skins[p.mo.skin].jumpfactor
		p.pflags = $ | (PF_THOKKED|PF_STARTJUMP)
		p.mo.state = S_PLAY_JUMP
		p.mo.kid.sprung = false
		p.mo.kid.unlockcontrols = false
		return true
	end
end)

local function KID_DoZADD(p, xy)
	local gravity = abs(P_GetMobjGravity(p.mo))
	if gravity
		local oldVelocity = abs(p.mo.momz)
		local distance = FixedDiv(FixedMul(oldVelocity, oldVelocity), gravity)
		local newVelocity = FixedSqrt(FixedMul(3*gravity, distance))
		p.mo.momz = FixedMul(FixedDiv($, oldVelocity), newVelocity)
		if xy
			p.mo.momx = FixedMul(FixedDiv($, oldVelocity), newVelocity)
			p.mo.momy = FixedMul(FixedDiv($, oldVelocity), newVelocity)
		end
	end
end

addHook("ThinkFrame", function()
	for p in players.iterate
		p.KID_LIVES = $ or 0
		if p.mo.skin == 'thekid'
			if not p.mo.kid
				local kid = {
					deathx = 0,
					deathy = 0,
					deathz = 0,
					sprung = false,
					usedown = false,
					bullets = 0,
					bloodtimer = 0,
					prevwater = false,
					steamjet = false,
					unlockcontrols = false,
					prevcarry = 0
				}
				p.mo.kid = kid
			end
			
			if p.playerstate == PST_LIVE
				
				if p.powers[pw_super] > 0
					P_KillMobj(p.mo) //lmfao.
				end
				
				if (mapheaderinfo[gamemap].typeoflevel & TOL_NIGHTS) 
					if (p.nightstime == 1) or p.powers[pw_carry] == CR_NIGHTSFALL
						P_DamageMobj(p.mo,nil,nil,1,DMG_INSTAKILL) --the only case where P_KillMobj wont work (see: https://cdn.discordapp.com/attachments/755212288675283025/782352145126785024/srb20422.gif)
						p.pflags = $ | PF_FINISHED
						p.mo.flags2 = $ | MF2_DONTDRAW
					end
				end
			
				if p.exiting > 1
				and (mapheaderinfo[gamemap].bonustype == 1
				or mapheaderinfo[gamemap].bonus == 2)
				and not (p.mo.state == S_PLAY_EPICWIN)
					p.mo.state = S_PLAY_EPICWIN
				end
								
				if p.mo.state == S_PLAY_JUMP
					p.mo.state = S_PLAY_KIDSTARTJUMP
				end
				
				if p.mo.state == S_PLAY_SPRING
					p.mo.state = S_PLAY_KIDJUMP
				end
				
				if p.mo.state == S_PLAY_KIDJUMP
				and P_MobjFlip(p.mo)*p.mo.momz < 0
					p.mo.state = S_PLAY_KIDFALL
				end
				
				if p.pflags & PF_SLIDING
					p.mo.kid.unlockcontrols = true
				end
				
				if p.mo.kid.steamjet
					p.mo.kid.steamjet = false
					KID_DoZADD(p)
				end
				
				if p.mo.kid.prevcarry and not p.powers[pw_carry]
					if p.mo.kid.prevcarry == CR_MACESPIN
					or p.mo.kid.prevcarry == CR_MINECART
					or p.mo.kid.prevcarry == CR_DUSTDEVIL
						KID_DoZADD(p, true)
						p.mo.kid.unlockcontrols = true
						p.secondjump = 4
						p.pflags = $ | P_GetJumpFlags(p)
					end
					p.mo.kid.prevcarry = 0
				end
				if not P_IsObjectOnGround(p.mo)
					p.secondjump = (p.secondjump == 4) and 4 or ($ + 2)
					if p.secondjump == 4
						p.mo.momz = $+(P_GetMobjGravity(p.mo)*2)
					end
					if p.secondjump == 2
					and not (p.pflags & PF_JUMPED)
					and not p.powers[pw_carry]
						p.pflags = $ | P_GetJumpFlags(p)
						p.mo.state = S_PLAY_KIDFALL
					end
					if p.mo.kid.sprung and p.mo.kid.prevwater 
					and P_MobjFlip(p.mo)*p.mo.momz > 0 and not (p.mo.eflags & MFE_UNDERWATER)
					and not p.powers[pw_justsprung]
						p.mo.kid.sprung = false
						KID_DoZADD(p)
					end
				else
					p.pflags = $ & ~ P_GetJumpFlags(p)
					p.mo.kid.unlockcontrols = false
					p.mo.kid.sprung = false
				end
				
				if p.mo.eflags & MFE_UNDERWATER
					p.pflags = $ & ~PF_THOKKED
				end
				
				if (p.cmd.forwardmove <= 25 and p.cmd.forwardmove >= -25 and p.cmd.sidemove <= 25 and p.cmd.sidemove >= -25)
				and not ((p.pflags & (PF_SLIDING|PF_STASIS|PF_FULLSTASIS)) or p.mo.kid.unlockcontrols or (p.mo.eflags & MFE_SPRUNG) or P_PlayerInPain(p) or p.powers[pw_carry])
					p.mo.momx = p.cmomx
					p.mo.momy = p.cmomy
				end
				
				if p.cmd.buttons & BT_USE and ((not p.mo.kid.usedown) or (not p.weapondelay)) and (p.mo.kid.bullets < 4)
					p.drawangle = p.mo.angle
					local bullet = P_SpawnPlayerMissile(p.mo, p.revitem)					
					p.mo.kid.bullets = $ + 1
					p.weapondelay = 8
					if bullet and bullet.valid
						bullet.fuse = 30
						if p.mysticsuper
							bullet.scale = 2*FRACUNIT
							bullet.radius = 8*FRACUNIT
							bullet.height = 8*FRACUNIT
						end
					end
				end
				
				p.mo.kid.prevcarry = p.powers[pw_carry]
				p.mo.kid.prevwater = (p.mo.eflags & MFE_UNDERWATER)
				p.mo.kid.usedown = (p.cmd.buttons & BT_USE)
				
			else
				p.mo.kid.deathx = $ or p.mo.x
				p.mo.kid.deathy = $ or p.mo.y
				p.mo.kid.deathz = $ or p.mo.z
				p.mo.momz = 0
				P_TeleportMove(p.mo, p.mo.kid.deathx, p.mo.kid.deathy, p.mo.kid.deathz)
				if p.deadtimer == -9*TICRATE and p.lives >= 1
					S_ChangeMusic("dedlol",false,p)
				elseif p.deadtimer < -9*TICRATE
					S_StopMusic(p)
				end
				if p.cmd.buttons & BT_JUMP 
				and p.deadtimer < 0 
				and p.deadtimer > -8*TICRATE 
				and p.playerstate == PST_DEAD 
					p.deadtimer = 54
				end
				if p.mo.kid.bloodtimer < TICRATE
					p.mo.kid.bloodtimer = $ + 1
					for i = 0, 5
						local blood = P_SpawnMobjFromMobj(p.mo,0,0,2*FRACUNIT, MT_KID_GIBS)
						blood.frame = P_RandomRange(E, G)
						blood.nuked = p.mo.kid.nuked
						blood.force = p.mo.kid.force
					end
				end
			end
		else
			p.mo.kid = nil
		end
	end
end)

addHook("PlayerSpawn", function(p)
	if p.mo and p.mo.valid
		if p.mo.skin == "thekid"
			//P_TeleportMove(p.mo, p.mo.x, p.mo.y, p.mo.z + 5*FRACUNIT*P_MobjFlip(p.mo))
		end
	end
end)

addHook("MobjDamage", function(kid)
    if kid and kid.valid and kid.player and kid.player.valid and kid.skin == "thekid"
		if kid.player.powers[pw_carry] != CR_NIGHTSMODE
			if kid.player.playerstate != PST_DEAD 
				P_KillMobj(kid)
				return true
			end
		else
			kid.player.powers[pw_carry] = CR_NIGHTSFALL
			P_TeleportMove(kid, kid.x, kid.y, kid.z + 5*FRACUNIT*P_MobjFlip(kid))
			return true
		end
    end
end)

addHook("MobjDeath", function(kid)
	if kid and kid.valid and kid.player and kid.player.valid and kid.skin == "thekid"
		if not kid.kid_popped
			S_StartSound(kid, sfx_kiddie)
			for gib = A, D
				local gibs = P_SpawnMobjFromMobj(kid,0,0,2*FRACUNIT, MT_KID_GIBS)
				gibs.frame = gib
				gibs.nuked = kid.kid_nuked
				gibs.burnt = kid.kid_burnt
				gibs.zapped = kid.kid_zapped
				gibs.force = kid.kid_force
				gibs.color = kid.player.skincolor
			end
		end
		if kid.player.lives >= 1
			S_StopMusic(kid.player)
			kid.player.deadtimer = -10*TICRATE
		end
		if G_GametypeUsesLives()
		and not G_IsSpecialStage()
			kid.player.KID_LIVES = $ - 1
		end
		if ultimatemode
			kid.player.lives = 0
		end
		return true
	end
end, MT_PLAYER)

addHook("MobjThinker", function(gib)
	if gib and gib.valid
	//TODO: ADD FUNCTIONALITY SOON
		if not gib.thrown
			if gib.nuked
				P_InstaThrust(gib, gib.angle, P_RandomRange(10,20)*FRACUNIT)
				P_SetObjectMomZ(gib, P_RandomRange(8,22)*FRACUNIT, false)
			else
				P_InstaThrust(gib, gib.angle, P_RandomRange(1,6)*FRACUNIT)
				P_SetObjectMomZ(gib, P_RandomRange(3,12)*FRACUNIT, false)
			end
			gib.thrown = true
		end
		if not P_IsObjectOnGround(gib)
			if not gib.exploded
				gib.rollangle = $ + FixedAngle(abs((gib.momz*3/2) + (P_RandomRange(1, 30)*FRACUNIT)))
			end
			if gib.force
				gib.momz = 0
			end
		else
			if gib.sprite == SPR_FPRT
				P_KillMobj(gib)
			else
				gib.momz = 0
			end
		end
		if (gib.momx == 0
		or gib.momy == 0
		or gib.momz == 0)
		and gib.nuked
		and not gib.exploded
			gib.state = S_BOSSEXPLODE
			S_StartSound(gib, sfx_cybdth)
			gib.exploded = true
		end
		if gib.exploded
			gib.momx = 0
			gib.momy = 0
			gib.momz = 0
		end
		if gib.burnt
			gib.colorized = true
			gib.color = SKINCOLOR_BLACK
			if leveltime % 15 == 0
				local smoke = P_SpawnMobjFromMobj(gib, 0,0,0, MT_SMOKE)
				smoke.momz = 2*FRACUNIT
			end
		end
		if gib.zapped
			if leveltime % P_RandomRange(5, 50) == 0
				P_SpawnMobjFromMobj(gib, P_RandomRange(1,10)*FRACUNIT, P_RandomRange(1,10)*FRACUNIT, P_RandomRange(1,10)*FRACUNIT, MT_WATERZAP)
				S_StartSound(gib, sfx_s3k5c)
			end
		end
		local fof = P_ThingOnSpecial3DFloor(gib)
		if fof and fof.valid
		and GetSecSpecial(fof.special, 1) == 3
			local smoke = P_SpawnMobjFromMobj(gib, 0,0,0, MT_SMOKE)
			smoke.momz = 2*FRACUNIT
			P_KillMobj(gib)
		end
	end
end, MT_KID_GIBS)

addHook("MobjSpawn", function(gib)
	if gib and gib.valid
		gib.angle = FixedAngle(((P_RandomRange(1,359))*FRACUNIT))
		gib.fuse = 10*TICRATE
	end
end, MT_KID_GIBS)

addHook("MobjThinker", function(bullet)
	if bullet and bullet.valid
		if prepfof(bullet.floorrover)
		and bullet.z == bullet.floorrover.topheight
			EV_CrumbleChain(bullet.floorrover)
		end
		if prepfof(bullet.ceilingrover)
		and (bullet.z + bullet.height) == bullet.ceilingrover.bottomheight
			EV_CrumbleChain(bullet.ceilingrover)
		end
	end
end, MT_KIDBULLET)

addHook("MobjFuse", function(bullet)
	if bullet and bullet.valid
		P_KillMobj(bullet)
		return true
	end
end, MT_KIDBULLET)

addHook("MobjMoveCollide", function(bullet,spike)
	if bullet and bullet.valid and spike and spike.valid
	and (spike.z <= bullet.z + bullet.height)
	and (bullet.z <= spike.z + spike.height)
		if spike.type == MT_SPIKE or spike.type == MT_WALLSPIKE or spike.type == MT_WALLSPIKEBASE
			P_KillMobj(spike)
			P_KillMobj(bullet)
		end
		local kid = bullet.target
		if spike.type == MT_STARPOST
		and kid
			if (multiplayer and (kid.player.starpostnum < spike.health)) or not multiplayer
				spike.state = S_STARPOST_SPIN
				S_StartSound(spike, sfx_strpst)
				local kiddo = kid.player
				kiddo.starposttime = 1
				kiddo.starpostx = kid.x>>FRACBITS
				kiddo.starposty = kid.y>>FRACBITS
				kiddo.starpostz = kid.z>>FRACBITS
				kiddo.starpostangle = kid.angle
				kiddo.starpostnum = spike.health
				kiddo.starpostscale = kid.destscale
				if spike.flags2 & MF2_OBJECTFLIP
					kiddo.starpostscale = $ * -1
				end
			end
			P_KillMobj(bullet)
		end
	end
end, MT_KIDBULLET)

local function doKidSpring(kid, spring)
    if kid and kid.valid and kid.player and kid.skin == "thekid" and kid.kid
		if spring and spring.valid
		and (spring.z <= kid.z + kid.height)
		and (kid.z <= spring.z + spring.height)
			if spring.flags & MF_SPRING
			or spring.type == MT_SPRINGSHELL
			or spring.type == MT_YELLOWSHELL
				//lach i feel so SORRY FOR YOU
				P_DoSpring(spring, kid)
				if spring.info.mass
					local gravity = abs(P_GetMobjGravity(kid))
					if gravity
						local oldVelocity = abs(kid.momz + FU)
						local distance = FixedDiv(FixedMul(oldVelocity, oldVelocity), gravity)
						local newVelocity = FixedSqrt(FixedMul(3*gravity, distance))
						if spring.info.damage
							kid.momx = FixedMul(FixedDiv($, oldVelocity), newVelocity)
							kid.momy = FixedMul(FixedDiv($, oldVelocity), newVelocity)
							kid.kid.unlockcontrols = true
						end
						kid.momz = FixedMul(FixedDiv($, oldVelocity), newVelocity)
					end
				end
				if not P_IsObjectOnGround(kid)
					kid.player.pflags = $ | P_GetJumpFlags(kid.player)
				end
				kid.player.pflags = $ & ~PF_THOKKED
				kid.kid.sprung = true
			end
			if spring.type == MT_STEAM
				kid.kid.steamjet = true
			end
		end
	end
end

addHook("MobjMoveCollide", doKidSpring, MT_PLAYER)
addHook("MobjCollide", doKidSpring, MT_PLAYER)

local function KID_SpawnSoundMobj(length, sound, source)
	local soundl = P_SpawnMobjFromMobj(source, 0,0,0, MT_THOK)
	soundl.fuse = length
	soundl.state = S_INVISIBLE
	S_StartSound(soundl, sound)
end

addHook("MobjDamage", function(enemy, bullet, kid)
	if enemy.valid and (enemy.flags & (MF_BOSS|MF_ENEMY))
		if bullet and bullet.valid and bullet.type == MT_KIDBULLET
		and kid and kid.valid and kid.player
			local bossmultiplier = (enemy.flags & MF_BOSS) and 6 or 3
			enemy.KID_HP = $==nil and bossmultiplier-1 or ($ - 1)
			if not enemy.KID_HP
				KID_SpawnSoundMobj(30, sfx_kiddie, enemy)
				enemy.KID_HP = bossmultiplier
				P_DamageMobj(enemy, bullet, kid)
				if not (enemy.health-1)
					enemy.KID_ShotToDeath = true
				end
			else
				KID_SpawnSoundMobj(4, sfx_kidhit, enemy)
				return true
			end
		end
	end
end)

local marioenemies = {
	MT_GOOMBA,
	MT_BLUEGOOMBA
}

for i = 1, #marioenemies
	addHook("MobjDeath", function(enemy, bullet, kid)
		if enemy.valid and enemy.KID_ShotToDeath
		and kid and kid.valid and kid.player
			enemy.fuse = TICRATE*3
			P_SetObjectMomZ(enemy, 7*FU, false)
			enemy.flags = ($| MF_NOCLIPHEIGHT)|($& ~MF_NOGRAVITY)
			enemy.tics = -1
			enemy.rollangle = FixedAngle(180*FU)
		end
	end, marioenemies[i])
	addHook("MobjThinker", function(enemy)
		if enemy.valid and enemy.KID_ShotToDeath
			P_SetObjectMomZ(enemy, -FU/2, true)
			enemy.state = S_SPAWNSTATE
		end
	end, marioenemies[i])
end

addHook("MobjDeath", function(monitor, bullet, kid)
	if monitor.valid and kid and kid.valid and kid.skin == 'thekid'
		P_KillMobj(monitor)
		for i = 1, 10
			local ring = P_SpawnMobjFromMobj(monitor, 0,0,0, MT_FLINGRING)
			P_InstaThrust(ring, FixedAngle(36*FU)*i, P_RandomFixed()+(FU*3))
			P_SetObjectMomZ(ring, P_RandomFixed()+(FU*3), false)
		end
		return true
	end
end, MT_RING_BOX)

/*addHook("ShieldSpecial", function(p)
	if p.mo.skin == 'thekid'
		local shield = (p.powers[pw_shield] & SH_NOSTACK)
		if shield == SH_ARMAGEDDON
			p.mo.kid_nuked = true
			P_KillMobj(p.mo)
			P_BlackOw(p)
			return true
		end
		if shield == SH_ELEMENTAL
		or shield == SH_FLAMEAURA
			p.mo.kid_burnt = true
			for i = 1, 80
				local fire = P_SpawnMobjFromMobj(p.mo, 0,0,0, MT_KID_GIBS)
				fire.sprite = SPR_FPRT
				fire.frame = A|TR_TRANS60
				P_InstaThrust(fire, FixedAngle(P_RandomRange(0, 360)*FRACUNIT), P_RandomRange(1, 10)*FRACUNIT)
				P_SetObjectMomZ(fire, P_RandomRange(1,5)*FRACUNIT, false)
			end
			P_KillMobj(p.mo)
			return true
		end
		if shield == SH_BUBBLEWRAP
			p.mo.kid_popped = true
			S_StartSound(p.mo, sfx_s3k77)
			P_KillMobj(p.mo)
			return true
		end
		if shield == SH_THUNDERCOIN
		or shield == SH_ATTRACT
			p.mo.kid_zapped = true
			local elec = P_SpawnMobjFromMobj(p.mo, 0, 0, 0, MT_THOK)
			elec.sprite = SPR_SHCK
			elec.scale = 3*FRACUNIT
			elec.rollangle = ANGLE_90
			elec.colorized = true
			elec.color = SKINCOLOR_GOLD
			S_StartSound(p.mo, P_RandomRange(sfx_litng2, sfx_litng4))
			P_KillMobj(p.mo)
			return true
		end
		if shield == SH_WHIRLWIND
			p.mo.kid_wind = true
			p.pflags = $ | PF_THOKKED
			S_StartSound(p.mo, sfx_wdjump)
			return true
		end
		if p.powers[pw_shield] & SH_FORCE
			p.mo.kid_force = true
			P_KillMobj(p.mo)
			return true
		end
	end
end) TODO: Fix this shit up lmao*/

hud.add(function(v, p)
	if (p.mo and p.mo.valid and p.mo.skin == "thekid")
	and p.playerstate == PST_DEAD
		if p.deadtimer >= -9*TICRATE 
			local patch = v.cachePatch("DEADLOL")
			local scale = 40*(FRACUNIT/100) // 40% scale
			local x = 160*FRACUNIT - ((patch.width / 2) * scale)
			local y = 100*FRACUNIT - ((patch.height / 2) * scale)
			v.drawScaled(x, y, scale, patch)
		end
	end
end)




hud.add(function(v,p)
	if p.mo and p.mo.valid and p.mo.skin == "thekid" 
	and not modeattacking
	and not ultimatemode
		if p.KID_LIVES != nil
		and G_GametypeUsesLives()
		and not G_IsSpecialStage()
			hud.disable("lives")
			local livesx = v.cachePatch("STLIVEX")
			local kid = v.getSprite2Patch(p.mo.skin, SPR2_XTRA, A)
			local flags = V_SNAPTOLEFT|V_SNAPTOBOTTOM|V_PERPLAYER|V_HUDTRANS
			local color = v.getColormap("thekid", p.mo.color)
			local backing = v.cachePatch("STLIVEBK")
			v.drawString(56, 184, p.KID_LIVES, flags)
			v.drawString(40, 176, "\x82 The Kid", flags, "thin")
			v.draw(38, 186, livesx, flags)
			v.drawScaled(16*FRACUNIT, 176*FRACUNIT, FRACUNIT/2, backing, flags)
			v.drawScaled(16*FRACUNIT, 176*FRACUNIT, FRACUNIT/2, kid, flags, color)
		end
	else
		hud.enable("lives")
	end	
end, "game")

